### HighWater.pl
### A plugin to track the highest entry number.
### Allows you to determine whether an entry is being
### built for the first time.
### Copyright 2003 by Eric James Stone
### http://www.ericjamesstone.com/
### version 1.00
### last modified 8 November 2003

### NOTE: You can manually create the file that HighWater uses to
###       store the number of the highest entry. Just place a file
###       named HighWater.txt in your main blog directory. On the
###       first line of that file, put the entry number of your latest
###       entry. That's all.
###
###       If you do not place the file there manually, HighWater will
###       create the file the first time you try to use one of the tags.
###       You will need to rebuild again after that happens.

package MT::Plugin::HighWater;
use MT::Template::Context;
MT::Template::Context->add_tag(GetHighWater => \&GetHighWater);										### <$MTGetHighWater$> returns highest entry number stored so far.
MT::Template::Context->add_tag(SetHighWater => \&SetHighWater);										### <$MTSetHighWater$> compares entry number to stored number, and stores it if it is higher.
MT::Template::Context->add_conditional_tag(IfNewHighWater => \&IfNewHighWater);   ### <MTIfHighWater>content</MTIfHighWater> displays content if current entry is the stored highest entry.
MT::Template::Context->add_conditional_tag(IfHighWater => \&IfHighWater);         ### <MTIfNewHighWater>content</MTIfNewHighWater> displays content if current entry number is higher than the stored highest entry, then stores current entry number as new highest.

sub GetHighWater {
  $ctx=shift;
	my $id        = $ctx->stash('blog')->id;
	my $site_path = $ctx->stash('blog')->site_path;
	$TextFile = $site_path."/HighWater.txt";						### Location of the file containing the highest entry number.
	open(INPUT,"$TextFile") || InitHighWater();
	my @hwf = <INPUT>;
	close(INPUT);
	my $hw = $hwf[0];
	return $hw;
}

sub IfNewHighWater {
  $ctx=shift;
	my $entry_id  = $ctx->stash('entry')->id;
	my $hw = GetHighWater($ctx);
	my $nhw = 0;
	$entry_id=$entry_id * 1;
	$hw = $hw * 1;
	if ($entry_id > $hw) {
		SetHighWater($ctx);
		$nhw = 1;
	}
	return $nhw;
}

sub IfHighWater {
  $ctx=shift;
	my $entry_id  = $ctx->stash('entry')->id;
	my $hw = GetHighWater($ctx);
	my $ihw = 0;
	$entry_id=$entry_id * 1;
	$hw = $hw * 1;
	if ($entry_id == $hw) {
		$ihw = 1;
	}
	return $ihw;
}


sub SetHighWater {
  $ctx=shift;
	my $site_path = $ctx->stash('blog')->site_path;
	my $entry_id  = $ctx->stash('entry')->id;
	my $hw = GetHighWater($ctx);
	$entry_id=$entry_id * 1;
	$hw = $hw * 1;
	if ($entry_id > $hw) {
		open(OUTPUT, ">$TextFile") || die "$!";
			print OUTPUT $entry_id;
		close (OUTPUT)
	}
	return $hw;
}

sub InitHighWater {
	open(OUTPUT, ">$TextFile") || die "$!";
		print OUTPUT "0";
	close (OUTPUT);
	die "$TextFile created. Please rebuild again and it should work.\n";
}



1;